@@ -74,7 +74,7 @@ def is_valid_time_range(time_range: tuple) -> bool:
     return True
 
 
-def validate_url(url):
+def validate_url(url: str):
     if url is not None or url != "":
         parsed_url = urlparse(url)
         return parsed_url.scheme and parsed_url.netloc
@@ -125,7 +125,7 @@ def is_valid_datetime_range(datetime_range: tuple) -> bool:
     return True
 
 
-def is_list_of_dicts(obj):
+def is_list_of_dicts(obj: object) -> bool:
     """
     Check if an object is a list of dictionaries.
 
@@ -138,14 +138,13 @@ def is_list_of_dicts(obj):
     Example:
         Usage of is_list_of_dicts:
 
-        >>> data = [{'name': 'Alice', 'age': 30}, {'name': 'Bob', 'age': 25}]
-        >>> result = is_list_of_dicts(data)
-        >>> print(result)
+        >>> is_list_of_dicts([{'name': 'Alice', 'age': 30}, {'name': 'Bob', 'age': 25}])
         True
 
-        >>> data = [1, 2, 3]
-        >>> result = is_list_of_dicts(data)
-        >>> print(result)
+        >>> is_list_of_dicts([1, 2, 3])
+        False
+
+        >>> is_list_of_dicts(1)
         False
     """
     IS_LIST_OF_DICTS_FUNCTION_NAME = "is_list_of_dicts"
@@ -251,7 +250,7 @@ def is_datetime_in_datetime_range(check_datetime: datetime, datetime_range: tupl
 # TODO Shall we create also createInternalServerErrorHttpResponse(), createOkHttpResponse() like we have in TypeScript?
 
 # Former name was create_http_headers()
-def create_authorization_http_headers(user_jwt: str):
+def create_authorization_http_headers(user_jwt: str) -> dict:
     http_headers = {
         'Content-Type': 'application/json',
         'Authorization': f'Bearer {user_jwt}',
@@ -259,7 +258,14 @@ def create_authorization_http_headers(user_jwt: str):
     return http_headers
 
 
-def create_return_http_headers():
+def get_jwt_from_event(event: dict) -> str:
+    auth_header = event.get('headers', {}).get('authorization')
+    if auth_header is None:
+        auth_header = event.get('headers', {}).get('Authorization')
+    return auth_header.split('Bearer ')[1]
+
+
+def create_return_http_headers() -> dict:
     return {
         "Content-Type": "application/json",
         "Access-Control-Allow-Origin": "*",
@@ -267,17 +273,17 @@ def create_return_http_headers():
 
 
 # https://google.github.io/styleguide/jsoncstyleguide.xml?showone=Property_Name_Format#Property_Name_Format
-def create_http_body(body):
+def create_http_body(body: dict) -> str:
     # TODO console.warning() if the body is not a valid camelCase JSON
     # https://stackoverflow.com/questions/17156078/converting-identifier-naming-between-camelcase-and-underscores-during-json-seria
     return json.dumps(body)
 
 
-def get_brand_name():
+def get_brand_name() -> str:
     return our_get_env("BRAND_NAME")
 
 
-def get_environment_name():
+def get_environment_name() -> str:
     environment_name = our_get_env("ENVIRONMENT_NAME")
     EnvironmentName(environment_name)  # if invalid, raises ValueError: x is not a valid EnvironmentName
     return environment_name
